pub struct TierInfo {
pub radius: f64,
pub mag_cap: f32,
pub members: u32,
pub first_pattern: u64,
pub n_patterns: u64,
pub n_anchors: u64,
}Expand description
One scale tier of the index.
Fields
radius: f64Disc radius, radians: patterns are drawn from stars within this of an anchor, so no pattern is wider than twice it.
mag_cap: f32Faintest magnitude considered for this tier.
members: u32Stars per anchor group (anchor included).
first_pattern: u64First pattern of the tier in the key and quad arrays.
n_patterns: u64Patterns in the tier.
n_anchors: u64Anchors (groups) that produced patterns.
Implementations